@@ -13,7 +13,7 @@
 
 class ProgressMonitor : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProgressMonitor(TQObject *parent = 0);
