@@ -35,7 +35,7 @@ class TDEAboutData;
   */
 class LikeBack : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
         enum Button { ILike = 0x01, IDoNotLike = 0x02, IFoundABug = 0x04, Configure = 0x10,
@@ -102,7 +102,7 @@ class LikeBack : public TQWidget
 
 class LikeBackDialog : public KDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
         LikeBackDialog(LikeBack::Button reason, TQString windowName, TQString context);
