@@ -20,7 +20,7 @@ namespace Tool { class Group; }
 //----------------------------------------------------------------------------
 class ProgrammerStatusWidget : public TQObject, public KeyPopupButton<TQString>
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProgrammerStatusWidget(TQWidget *parent);
@@ -36,7 +36,7 @@ private slots:
 //----------------------------------------------------------------------------
 class ToolStatusWidget : public TQObject, public KeyPopupButton<TQString>
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ToolStatusWidget(TQWidget *parent);
@@ -53,7 +53,7 @@ private slots:
 //----------------------------------------------------------------------------
 class ViewMenuAction : public TDEToggleAction
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ViewMenuAction(KDockWidget *widget);
@@ -71,7 +71,7 @@ private:
 //----------------------------------------------------------------------------
 class MenuBarButton : public TQToolButton
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MenuBarButton(const TQString &icon, TQWidget *parent);
