@@ -16,7 +16,7 @@ namespace Icd1
 class XmlToData : public Programmer::XmlToData<Data>
 {
 public:
-  XmlToData() : Programmer::XmlToData<Data>("icd1", "Icd1") {}
+  XmlToData(const TQString &folder) : Programmer::XmlToData<Data>(folder, "icd1", "Icd1") {}
 
 private:
   virtual void parseData(TQDomElement element, Data &data);
