@@ -20,7 +20,7 @@ class Group;
 //----------------------------------------------------------------------------
 class AdvancedDialog : public ::Programmer::PicAdvancedDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   AdvancedDialog(ProgrammerBase &base, TQWidget *parent);
