@@ -17,7 +17,7 @@ namespace Pickit2
 //----------------------------------------------------------------------------
 class Base : public Pickit::Base
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Base(const Programmer::Group &group, const Pic::Data *data) : Pickit::Base(group, data) {}
