@@ -16,7 +16,7 @@ namespace Pickit2Bootloader
 {
 class ConfigWidget: public ::Programmer::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(const::Programmer::Group &group, TQWidget *parent);
