@@ -19,7 +19,7 @@ namespace TinyBootloader
 {
 class ConfigWidget: public ::Programmer::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(const ::Programmer::Group &group, TQWidget *parent);
