@@ -16,7 +16,7 @@ namespace CCSC
 
 class CompileFile : public Compile::Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString deviceName() const { return TQString(); }
